maxIconSize property
The highest size this Icon widget can have when the device size (width) is bigger than DeviceSizes.tablet width.
Implementation
final double maxIconSize;
The highest size this Icon widget can have when the device size (width) is bigger than DeviceSizes.tablet width.
final double maxIconSize;