maxFontSize property
The highest size this Text widget can have when the device size (width) is bigger than DeviceSizes.tablet width. The default maxFontSize is 20;
Implementation
final double maxFontSize;
The highest size this Text widget can have when the device size (width) is bigger than DeviceSizes.tablet width. The default maxFontSize is 20;
final double maxFontSize;